@@ -69,7 +69,7 @@ def write_frag_info(
         existing. Default is the current directory.
     """
 
-    records = SeqIO.parse(fasta, "fasta")
+    records = SeqIO.parse(hio.read_compressed(fasta), "fasta")
 
     try:
         info_contigs_path = os.path.join(output_dir, output_contigs)
@@ -401,7 +401,7 @@ def frag_len(
         ax.set_xlabel("Fragment length [bp]")
         ax.set_ylabel("Log10 number of fragments")
         ax.set_title("Distribution of restriction fragment length")
-        ax.set_yscale("log", basey=10)
+        ax.set_yscale("log", base=10)
         ax.annotate(
             "Total fragments: {}".format(nfrags),
             xy=(0.95, 0.95),
